@@ -19,8 +19,6 @@
 #ifndef ETHERAPE_CAPTURE_H
 #define ETHERAPE_CAPTURE_H
 
-#include "links.h"
-
 /* Possible states of capture status */
 enum status_t
 {
@@ -38,5 +36,6 @@ gboolean pause_capture (void);
 gboolean stop_capture (void);
 void cleanup_capture (void);
 gint set_filter (gchar * filter, gchar * device);
+gchar *get_default_filter (apemode_t mode);
 
 #endif
