@@ -31,6 +31,7 @@
 #include "protocols.h"
 #include "datastructs.h"
 #include "capture.h"
+#include "conversations.h"
 
 /* maximum node and link size */
 #define MAX_NODE_SIZE 5000
@@ -151,7 +152,7 @@ void dump_stats(guint32 diff_msecs)
   long ipc=ipcache_active_entries();
   status_string = g_strdup_printf (
     _("Nodes: %d (on canvas:%d, shown: %u), Links: %d, Conversations: %ld, "
-      "names %ld, protocols %ld. Total Packets seen: %lu (in memory: %d, "
+      "names %ld, protocols %ld. Total Packets seen: %lu (in memory: %ld, "
       "on list %ld). IP cache entries %ld. Canvas objs: %ld. Refreshed: %u ms"),
                                    node_count(), 
                                    g_tree_nnodes(canvas_nodes), displayed_nodes, 
@@ -162,7 +163,7 @@ void dump_stats(guint32 diff_msecs)
                                    canvas_obj_count,
                                    (unsigned int) diff_msecs);
   
-  g_my_info (status_string);
+  g_my_info ("%s", status_string);
   g_free(status_string);
 }
 
@@ -372,7 +373,7 @@ diagram_update_links(GtkWidget * canvas)
 guint
 update_diagram (GtkWidget * canvas)
 {
-  static struct timeval last_time = { 0, 0 }, diff;
+  static struct timeval last_refresh_time = { 0, 0 }, diff;
   guint32 diff_msecs;
   enum status_t status;
 
@@ -421,17 +422,17 @@ update_diagram (GtkWidget * canvas)
   /* With this we make sure that we don't overload the
    * CPU with redraws */
 
-  if ((last_time.tv_sec == 0) && (last_time.tv_usec == 0))
-    last_time = now;
+  if ((last_refresh_time.tv_sec == 0) && (last_refresh_time.tv_usec == 0))
+    last_refresh_time = now;
 
   /* Force redraw */
   while (gtk_events_pending ())
     gtk_main_iteration ();
 
   gettimeofday (&now, NULL);
-  diff = substract_times (now, last_time);
+  diff = substract_times (now, last_refresh_time);
   diff_msecs = diff.tv_sec * 1000 + diff.tv_usec / 1000;
-  last_time = now;
+  last_refresh_time = now;
 
   already_updating = FALSE;
 
@@ -782,11 +783,11 @@ display_node (node_t * node)
 
   /* Remove canvas_node if node is too old */
   if (IS_OLDER (diff, pref.gui_node_timeout_time)
-      && pref.gui_node_timeout_time && !node->node_stats.n_packets)
+      && pref.gui_node_timeout_time && !node->node_stats.pkt_list.length)
     return FALSE;
 
 #if 1
-  if ((pref.gui_node_timeout_time == 1) && !node->node_stats.n_packets)
+  if ((pref.gui_node_timeout_time == 1) && !node->node_stats.pkt_list.length)
     g_my_critical ("Impossible situation in display node");
 #endif
 
@@ -1265,7 +1266,7 @@ node_item_event (GnomeCanvasItem * item, GdkEvent * event,
           if (DEBUG_ENABLED)
             {
               gchar *msg = node_dump(node);
-              g_my_debug(msg);
+              g_my_debug("%s", msg);
               g_free(msg);
             }
         }
