@@ -31,12 +31,12 @@
     use sprintf - at your risk!
 */
 
+/* TODO implement IPv6 resolver */
+
 
 #include <config.h>
-
 #ifdef USE_DIRECTDNS
 
-
 #include <sys/types.h>
 #include <time.h>
 #include <sys/time.h>
@@ -60,6 +60,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
+#include "common.h"
 #include "ip-cache.h"
 #include "util.h"
 #include "direct_resolve.h"
@@ -84,7 +85,6 @@ typedef unsigned char byte;
 typedef unsigned short word;
 typedef unsigned long dword;
 
-
 #define OpcodeCount 3
 char *opcodes[OpcodeCount + 1] = {
   "standard query",
@@ -212,8 +212,8 @@ packetheader;
                                           ((x)[-2] <<  8) | ((x)[-1] <<  0))))
 #endif
 
-uint32_t alignedip;
-uint32_t localhost;
+static uint32_t alignedip;
+static uint32_t localhost;
 
 
 /*#define Debug 1*/
@@ -235,22 +235,27 @@ static int resfd = -1;			/* socket file descr. */
 static char tempstring[256];		/* temporary string used as buffer ... */
 
 /* internal funcs fwd decls */
-void direct_events (double *sinterval);
+static void direct_ready (gpointer data, gint fd, GdkInputCondition cond);
+static void direct_ack (void);
 
-static uint32_t
-longipstr (char *s)
+static char * strlongip_v4(uint32_t ip)
 {
-  return inet_addr (s);
+  address_t address;
+  address_clear(&address);
+  address.type = AF_INET;
+  address.addr32_v4 = ip;
+  return strlongip(&address);
 }
 
-int
-direct_waitfd (void)
+/* Callback function everytime a dns_lookup function is finished */
+static void
+direct_ready (gpointer data, gint fd, GdkInputCondition cond)
 {
-  return resfd;
+  direct_ack ();
 }
 
 /* called to activate the resolver */
-void
+int 
 direct_open (void)
 {
   int option, i;
@@ -280,10 +285,16 @@ direct_open (void)
 	       strerror (errno));
       exit (-1);
     }
-  localhost = longipstr ("127.0.0.1");
+  localhost = inet_addr ("127.0.0.1");
 
   /* cache activation */  
   ipcache_init();
+
+  g_my_debug ("File descriptor for DNS is %d", resfd);
+  gdk_input_add (resfd,
+                 GDK_INPUT_READ, direct_ready, NULL);
+
+  return 0;
 }
 
 /* closes the resolver */
@@ -296,12 +307,6 @@ direct_close(void)
    resfd= -1;   
 }
 
-/* returns 1 if the current dns implementation has a socket wich needs a select() */
-int direct_hasfd(void)
-{
-   return 1;
-}
-
 static void
 restell (char *s)
 {
@@ -337,22 +342,21 @@ dorequest (char *s, int type, word id)
 
 /* creates a request, asking DNS for its name */
 static void
-sendrequest_inverse (uint32_t ip)
+sendrequest_inverse (address_t *address)
 {
   struct ipcache_item *rp = NULL;
-  rp = ipcache_prepare_request(ip);
+  rp = ipcache_prepare_request(address);
 
   /* sending the request */
   snprintf (tempstring, sizeof (tempstring), "%u.%u.%u.%u.in-addr.arpa",
-	    ((byte *) & rp->ip)[3],
-	    ((byte *) & rp->ip)[2],
-	    ((byte *) & rp->ip)[1], ((byte *) & rp->ip)[0]);
+	    rp->ip.addr_v4[3], rp->ip.addr_v4[2], 
+	    rp->ip.addr_v4[1], rp->ip.addr_v4[0]);
   dorequest (tempstring, T_PTR, rp->id);
   if (debug)
     {
       snprintf (tempstring, sizeof (tempstring),
 		"Resolver: Sent domain lookup request for \"%s\".",
-		strlongip (rp->ip));
+		strlongip (&rp->ip));
       restell (tempstring);
     } 
 }
@@ -404,10 +408,9 @@ parserespacket_noerror (byte * s, int l, struct ipcache_item *rp,
     {
       /* Construct expected query reply */
       snprintf (stackstring, sizeof (stackstring),
-		"%u.%u.%u.%u.in-addr.arpa",
-		((byte *) & rp->ip)[3],
-		((byte *) & rp->ip)[2],
-		((byte *) & rp->ip)[1], ((byte *) & rp->ip)[0]);
+          "%u.%u.%u.%u.in-addr.arpa",
+          rp->ip.addr_v4[3], rp->ip.addr_v4[2],
+          rp->ip.addr_v4[1], rp->ip.addr_v4[0]);
     }
   else
     *stackstring = '\0';
@@ -561,13 +564,13 @@ parserespacket_noerror (byte * s, int l, struct ipcache_item *rp,
 		    restell (tempstring);
 		    return;
 		  }
-		if (memcmp (&rp->ip, (uint32_t *) c, sizeof (uint32_t)))
+		if (memcmp (&rp->ip.addr32_v4, (uint32_t *) c, sizeof (uint32_t)))
 		  {
 		    snprintf (tempstring, sizeof (tempstring),
 			      "Resolver: Reverse authentication failed: %s != ",
-			      strlongip (rp->ip));
+			      strlongip (&rp->ip));
 		    memcpy (&alignedip, (uint32_t *) c, sizeof (uint32_t));
-		    safe_strncat (tempstring, strlongip (alignedip),
+		    safe_strncat (tempstring, strlongip_v4 (alignedip),
 				  sizeof (tempstring));
 		    restell (tempstring);
 		    res_hostipmismatch++;
@@ -577,7 +580,7 @@ parserespacket_noerror (byte * s, int l, struct ipcache_item *rp,
 		  {
 		    snprintf (tempstring, sizeof (tempstring),
 			      "Resolver: Reverse authentication complete: %s == \"%s\".",
-			      strlongip (rp->ip),
+			      strlongip (&rp->ip),
 			      (rp->fq_hostname) ? rp->fq_hostname : "");
 		    restell (tempstring);
 		    res_reversesuccess++;
@@ -747,7 +750,7 @@ direct_ack ()
 	{
 	  snprintf (tempstring, sizeof (tempstring),
 		    "Resolver error: Received reply from unknown source: %s",
-		    strlongip (from.sin_addr.s_addr));
+		    strlongip_v4 (from.sin_addr.s_addr));
 	  restell (tempstring);
 	}
       else
@@ -761,14 +764,17 @@ direct_ack ()
     }
 }
 
-char *
-direct_lookup (uint32_t ip, int fqdn)
+const char *
+direct_lookup (address_t *ip)
 {
-  char *ipname;
+  const char *ipname;
   int is_expired = 0;
-  
+
+  if (ip->type != AF_INET)
+    return NULL;
+
   /* asks cache */
-  ipname = ipcache_getnameip(ip, fqdn, &is_expired);
+  ipname = ipcache_getnameip(ip, &is_expired);
 
   if (is_expired)
     {
