@@ -23,14 +23,13 @@
 #include "direct_resolve.h"
 #include "thread_resolve.h"
 
-
 /* initialize dns interface */
-void dns_open (void)
+int dns_open (void)
 {
 #ifdef USE_DIRECTDNS
-   direct_open();
+   return direct_open();
 #else
-   thread_open();
+   return thread_open();
 #endif   
 }
 
@@ -44,44 +43,13 @@ void dns_close(void)
 #endif   
 }
 
-/* returns 1 if the current dns implementation has a socket wich needs a select() */
-int dns_hasfd(void)
+/* resolves address and returns its fqdn */
+const char *dns_lookup (address_t *address)
 {
 #ifdef USE_DIRECTDNS
-   return direct_hasfd();
+   return direct_lookup (address);
 #else
-   return thread_hasfd();
-#endif   
-}
-
-/* returns the file descriptor associated with dns socket */
-int dns_waitfd (void)
-{
-#ifdef USE_DIRECTDNS
-   return direct_waitfd();
-#else
-   return thread_waitfd();
-#endif   
-}
-
-/* called when the dns_waitfd socket has available data */
-void dns_ack (void)
-{
-#ifdef USE_DIRECTDNS
-   return direct_ack();
-#else
-   return thread_ack();
-#endif   
-}
-
-/* resolves address and returns its fqdn (if the corresponding parameter is nonzero)
-   or just the hostname (if fqdn is zero) */
-char *dns_lookup (uint32_t address, int fqdn)
-{
-#ifdef USE_DIRECTDNS
-   return direct_lookup (address, fqdn);
-#else
-   return thread_lookup (address, fqdn);
+   return thread_lookup (address);
 #endif   
 }
 
