@@ -41,6 +41,7 @@ typedef enum
   PROTO_COLUMN_PORT,
   PROTO_COLUMN_INSTANTANEOUS,
   PROTO_COLUMN_ACCUMULATED,
+  PROTO_COLUMN_AVGSIZE,
   PROTO_COLUMN_LASTHEARD,
   PROTO_COLUMN_PACKETS,
   PROTO_COLUMN_N        /* must be the last entry */
@@ -318,6 +319,16 @@ protocols_table_compare (GtkTreeModel * gs, GtkTreeIter * a, GtkTreeIter * b,
       else
 	ret = 1;
       break;
+    case PROTO_COLUMN_AVGSIZE:
+      t1 = prot1->rowstats.avg_size;
+      t2 = prot2->rowstats.avg_size;
+      if (t1 == t2)
+	ret = 0;
+      else if (t1 < t2)
+	ret = -1;
+      else
+	ret = 1;
+      break;
     case PROTO_COLUMN_LASTHEARD:
       time1 = prot1->rowstats.last_time;
       time2 = prot2->rowstats.last_time;
@@ -358,11 +369,11 @@ static GtkListStore *create_protocols_table (GtkWidget *window)
   if (gs)
     return gs;
 
-  /* create the store  - it uses 8 values, six displayable, one proto color 
+  /* create the store  - it uses 9 values, 7 displayable, one proto color 
      and the data pointer */
-  gs = gtk_list_store_new (8, GDK_TYPE_COLOR, G_TYPE_STRING, G_TYPE_STRING,
+  gs = gtk_list_store_new (9, GDK_TYPE_COLOR, G_TYPE_STRING, G_TYPE_STRING,
 			   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, 
-			   G_TYPE_STRING, G_TYPE_POINTER);
+			   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
   gtk_tree_view_set_model (gv, GTK_TREE_MODEL (gs));
 
   /* the view columns and cell renderers must be also created ... 
@@ -384,6 +395,7 @@ static GtkListStore *create_protocols_table (GtkWidget *window)
   create_add_text_column(gv, "Port", PROTO_COLUMN_PORT, TRUE);
   create_add_text_column(gv, "Inst Traffic", PROTO_COLUMN_INSTANTANEOUS, FALSE);
   create_add_text_column(gv, "Accum Traffic", PROTO_COLUMN_ACCUMULATED, FALSE);
+  create_add_text_column(gv, "Avg Size", PROTO_COLUMN_AVGSIZE, FALSE);
   create_add_text_column(gv, "Last Heard", PROTO_COLUMN_LASTHEARD, FALSE);
   create_add_text_column(gv, "Packets", PROTO_COLUMN_PACKETS, FALSE);
 
@@ -423,7 +435,7 @@ static void protocols_table_clear(GtkListStore *gs)
 static void update_protocols_row(GtkListStore *gs, GtkTreeIter *it, 
                                  const protocol_list_item_t *row_proto)
 {
-  gchar *ga, *gb, *gc, *gd, *ge;
+  gchar *ga, *gb, *gc, *gd, *ge, *gf;
   const port_service_t *ps;
   
   ga = traffic_to_str (row_proto->rowstats.accumulated, FALSE);
@@ -435,19 +447,23 @@ static void update_protocols_row(GtkListStore *gs, GtkTreeIter *it,
     gc = g_strdup("-");
   gd = traffic_to_str (row_proto->rowstats.average, TRUE);
   ge = timeval_to_str (row_proto->rowstats.last_time);
+  gf = traffic_to_str (row_proto->rowstats.avg_size, FALSE);
 
   gtk_list_store_set (gs, it, 
                       PROTO_COLUMN_ACCUMULATED, ga, 
                       PROTO_COLUMN_PACKETS, gb,
                       PROTO_COLUMN_PORT, gc,
                       PROTO_COLUMN_INSTANTANEOUS, gd,
-                      PROTO_COLUMN_LASTHEARD, ge, -1);
+                      PROTO_COLUMN_LASTHEARD, ge, 
+                      PROTO_COLUMN_AVGSIZE, gf, 
+                      -1);
 
   g_free(ga);
   g_free(gb);
   g_free(gc);
   g_free(gd);
   g_free(ge);
+  g_free(gf);
 }
 
 static void update_protocols_table(GtkWidget *window, const protostack_t *pstk)
@@ -533,66 +549,6 @@ static void update_protocols_table(GtkWidget *window, const protostack_t *pstk)
     }
 }
 
-/* common function to activate the proto columns */
-static void
-activate_protocols_info_column (GtkMenuItem * gm, guint column)
-{
-  GtkTreeViewColumn *gc;
-  GtkTreeView *gv = GTK_TREE_VIEW (glade_xml_get_widget (xml, "prot_clist"));
-  if (!gv)
-    return;			/* no window, no handling */
-
-  gc = gtk_tree_view_get_column (gv, column);
-  if (!gc)
-    return;
-  gtk_tree_view_column_set_visible (gc,
-				    gtk_check_menu_item_get_active
-				    (GTK_CHECK_MENU_ITEM (gm)));
-}				/* on_prot_column_view_activate */
-
-void
-on_prot_color_column_activate (GtkMenuItem * gm, gpointer * user_data)
-{
-  activate_protocols_info_column (gm, PROTO_COLUMN_COLOR);
-}
-
-void
-on_protocol_column_activate (GtkMenuItem * gm, gpointer * user_data)
-{
-  activate_protocols_info_column (gm, PROTO_COLUMN_NAME);
-}
-
-void
-on_port_column_activate (GtkMenuItem * gm, gpointer * user_data)
-{
-  activate_protocols_info_column (gm, PROTO_COLUMN_PORT);
-}
-
-void
-on_instant_column_activate (GtkMenuItem * gm, gpointer * user_data)
-{
-  activate_protocols_info_column (gm, PROTO_COLUMN_INSTANTANEOUS);
-}
-
-void
-on_accumulated_column_activate (GtkMenuItem * gm, gpointer * user_data)
-{
-  activate_protocols_info_column (gm, PROTO_COLUMN_ACCUMULATED);
-}
-
-void
-on_heard_column_activate (GtkMenuItem * gm, gpointer * user_data)
-{
-  activate_protocols_info_column (gm, PROTO_COLUMN_LASTHEARD);
-}
-
-void
-on_packets_column_activate (GtkMenuItem * gm, gpointer * user_data)
-{
-  activate_protocols_info_column (gm, PROTO_COLUMN_PACKETS);
-}
-
-
 /* ----------------------------------------------------------
 
    General Protocol Info window functions (protocols_window)
@@ -612,7 +568,7 @@ update_protocols_window (void)
   if (!gv)
     {
       /* register gv */
-      gv = gv = GTK_TREE_VIEW (glade_xml_get_widget (xml, "prot_clist"));
+      gv = GTK_TREE_VIEW (glade_xml_get_widget (xml, "prot_clist"));
       if (!gv)
         {
           g_critical("can't find prot_clist");
@@ -765,13 +721,13 @@ update_stats_info_windows (void)
   GtkWidget *window;
   enum status_t status;
   struct timeval diff;
-  static struct timeval last_time = {
+  static struct timeval last_update_time = {
     0, 0
   };
 
   status = get_capture_status();
 
-  diff = substract_times (now, last_time);
+  diff = substract_times (now, last_update_time);
   /* Update info windows at most twice a second */
   if (pref.refresh_period < 500)
     if (!(IS_OLDER (diff, 500)))
@@ -803,7 +759,7 @@ update_stats_info_windows (void)
 	}
     }
 
-  last_time = now;
+  last_update_time = now;
 }				/* update_stats_info_windows */
 
 
@@ -849,6 +805,9 @@ stats_info_create(const gchar *idkey, gpointer key)
   register_glade_widget(xml_info_window, G_OBJECT (window), "node_iproto_accum");
   register_glade_widget(xml_info_window, G_OBJECT (window), "node_iproto_accum_in");
   register_glade_widget(xml_info_window, G_OBJECT (window), "node_iproto_accum_out");
+  register_glade_widget(xml_info_window, G_OBJECT (window), "node_iproto_avgsize");
+  register_glade_widget(xml_info_window, G_OBJECT (window), "node_iproto_avgsize_in");
+  register_glade_widget(xml_info_window, G_OBJECT (window), "node_iproto_avgsize_out");
 
   /* get and register the tree view */
   gv = GTK_TREE_VIEW (glade_xml_get_widget (xml_info_window, "node_iproto_proto"));
@@ -877,12 +836,15 @@ stats_info_update(GtkWidget *window, const traffic_stats_t *stats,
     {
       update_gtklabel(window, "node_iproto_avg", "X");
       update_gtklabel(window, "node_iproto_accum", "X");
+      update_gtklabel(window, "node_iproto_avgsize", "X");
       if (!totals_only)
         {
           update_gtklabel(window, "node_iproto_avg_in", "X");
           update_gtklabel(window, "node_iproto_avg_out", "X");
           update_gtklabel(window, "node_iproto_accum_in", "X");
           update_gtklabel(window, "node_iproto_accum_out", "X");
+          update_gtklabel(window, "node_iproto_avgsize_in", "X");
+          update_gtklabel(window, "node_iproto_avgsize_out", "X");
         }
       update_protocols_table(window, NULL);
       gtk_widget_queue_resize (GTK_WIDGET (window));
@@ -896,6 +858,9 @@ stats_info_update(GtkWidget *window, const traffic_stats_t *stats,
       str = traffic_to_str (stats->stats.accumulated, FALSE);
       update_gtklabel(window, "node_iproto_accum", str);
       g_free(str);
+      str = traffic_to_str (stats->stats.avg_size, FALSE);
+      update_gtklabel(window, "node_iproto_avgsize", str);
+      g_free(str);
       if (!totals_only)
         {
           str = traffic_to_str (stats->stats_in.average, TRUE);
@@ -910,6 +875,12 @@ stats_info_update(GtkWidget *window, const traffic_stats_t *stats,
           str = traffic_to_str (stats->stats_out.accumulated, FALSE);
           update_gtklabel(window, "node_iproto_accum_out", str);
           g_free(str);
+          str = traffic_to_str (stats->stats_in.avg_size, FALSE);
+          update_gtklabel(window, "node_iproto_avgsize_in", str);
+          g_free(str);
+          str = traffic_to_str (stats->stats_out.avg_size, FALSE);
+          update_gtklabel(window, "node_iproto_avgsize_out", str);
+          g_free(str);
         }
       /* update protocol table */
       update_protocols_table(window, &stats->stats_protos);
