@@ -104,8 +104,8 @@ void link_delete(link_t *link)
   g_assert(link);
 
   /* first, free any conversation belonging to the link */
-  delete_conversation_link( *((guint32 *)(link->link_id.src.addr.ip4)), 
-                            *((guint32 *)(link->link_id.dst.addr.ip4)));
+  delete_conversation_link (&link->link_id.src.addr.ip, 
+                            &link->link_id.dst.addr.ip);
   
   for (i = STACK_SIZE; i + 1; i--)
     if (link->main_prot[i])
@@ -129,19 +129,13 @@ gfunc_remove_link(gpointer data, gpointer user_data)
 static gint
 update_link(link_id_t* link_id, link_t * link, gpointer delete_list_ptr)
 {
-  double pkt_expire_time;
   struct timeval diff;
 
   g_assert(delete_list_ptr);
 
-  /* calculate the right expiration interval */
-  if (pref.link_timeout_time && pref.link_timeout_time < pref.averaging_time)
-    pkt_expire_time = pref.link_timeout_time;
-  else
-    pkt_expire_time = pref.averaging_time;
-
   /* update stats - returns true if there are active packets */
-  if (traffic_stats_update(&link->link_stats, pkt_expire_time, pref.proto_link_timeout_time))
+  if (traffic_stats_update(&link->link_stats, pref.averaging_time, 
+                            pref.proto_link_timeout_time))
     {
       /* packet(s) active, update the most used protocols for this link */
       guint i = STACK_SIZE;
