@@ -45,10 +45,12 @@ init_menus (void)
   if (!interfaces)
     {
       g_my_info (_("No suitables interfaces for capture have been found"));
-      g_string_free(err_str, TRUE);
+      if (err_str)
+         g_string_free(err_str, TRUE);
       return;
     }
-  g_string_free(err_str, TRUE);
+  if (err_str)
+    g_string_free(err_str, TRUE);
 
   widget = glade_xml_get_widget (xml, "interfaces_menu");
 
@@ -78,8 +80,9 @@ init_menus (void)
       interfaces = interfaces->next;
     }
 
-  g_my_info (info_string->str);
-  g_string_free(info_string, TRUE);
+  g_my_info ("%s", info_string->str);
+  if (info_string)
+     g_string_free(info_string, TRUE);
 
   interface_list_free(interfaces);
 }				/* init_menus */
@@ -156,9 +159,9 @@ on_interface_radio_activate (gchar * gui_device)
 void
 on_mode_radio_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-  apemode_t new_mode = DEFAULT;
+  apemode_t new_mode = APEMODE_DEFAULT;
   const gchar *menuname = NULL;
-
+  gchar *filter;
 
   if (in_start_capture)
     return;			/* Disregard when called because
@@ -170,12 +173,8 @@ on_mode_radio_activate (GtkMenuItem * menuitem, gpointer user_data)
   g_my_debug ("Initial mode in on_mode_radio_activate %s",
 	      (gchar *) menuname);
 
-  if (!strcmp ("ieee802_radio", menuname))
-    new_mode = IEEE802;
-  else if (!strcmp ("fddi_radio", menuname))
-    new_mode = FDDI;
-  else if (!strcmp ("ethernet_radio", menuname))
-    new_mode = ETHERNET;
+  if (!strcmp ("link_radio", menuname))
+    new_mode = LINK6;
   else if (!strcmp ("ip_radio", menuname))
     new_mode = IP;
   else if (!strcmp ("tcp_radio", menuname))
@@ -196,32 +195,19 @@ on_mode_radio_activate (GtkMenuItem * menuitem, gpointer user_data)
   g_my_debug ("Mode menuitem active: %d",
 	      GTK_CHECK_MENU_ITEM (menuitem)->active);
 
-  switch (linktype)
-    {
-    case L_NULL:
-    case L_RAW:
-      if ((new_mode == ETHERNET) || (new_mode == FDDI)
-	  || (new_mode == IEEE802))
-	return;
-      break;
-    case L_EN10MB:
-      if ((new_mode == FDDI) || (new_mode == IEEE802))
-	return;
-      break;
-    case L_FDDI:
-      if (new_mode == ETHERNET || (new_mode == IEEE802))
-	return;
-      break;
-    case L_IEEE802:
-      if (new_mode == ETHERNET || (new_mode == FDDI))
-	return;
-      break;
-    default:
-      return;
-    }
+  if (!has_linklevel() && new_mode == LINK6)
+    return;
 
   if (!gui_stop_capture ())
      return;
+
+  /* if old filter was still default, we can change to default of new mode */
+  filter = get_default_filter(pref.mode);
+  if (!strcmp(pref.filter, filter))
+    {
+      g_free(pref.filter);
+      pref.filter = get_default_filter(new_mode);
+    }
   pref.mode = new_mode;
   g_my_info (_("Mode set to %s in GUI"), (gchar *) menuitem);
   gui_start_capture ();
@@ -321,6 +307,19 @@ on_about1_activate (GtkMenuItem * menuitem, gpointer user_data)
 }				/* on_about1_activate */
 
 
+void
+on_help_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+  GError *err = NULL;
+  gboolean success = FALSE;
+
+#if GTK_CHECK_VERSION(2, 13, 1)
+  success = gtk_show_uri (NULL, "ghelp:" PACKAGE_NAME, GDK_CURRENT_TIME, &err);
+#else
+  success = gnome_help_display (PACKAGE_NAME ".xml", NULL, &err);
+#endif
+}
+
 /* Helper functions */
 
 /* Sets up the GUI to reflect changes and calls start_capture() */
@@ -367,66 +366,18 @@ gui_start_capture (void)
   widget = glade_xml_get_widget (xml, "pause_menuitem");
   gtk_widget_set_sensitive (widget, TRUE);
 
-  /* Enable and disable mode buttons */
-
-  switch (linktype)
-    {
-    case L_NULL:
-    case L_RAW:
-#ifdef DLT_LINUX_SLL
-    case L_LINUX_SLL:
-#endif
-      widget = glade_xml_get_widget (xml, "ieee802_radio");
-      gtk_widget_set_sensitive (widget, FALSE);
-      widget = glade_xml_get_widget (xml, "fddi_radio");
-      gtk_widget_set_sensitive (widget, FALSE);
-      widget = glade_xml_get_widget (xml, "ethernet_radio");
-      gtk_widget_set_sensitive (widget, FALSE);
-      break;
-    case L_FDDI:
-      widget = glade_xml_get_widget (xml, "fddi_radio");
-      gtk_widget_set_sensitive (widget, TRUE);
-      widget = glade_xml_get_widget (xml, "ethernet_radio");
-      gtk_widget_set_sensitive (widget, FALSE);
-      widget = glade_xml_get_widget (xml, "ieee802_radio");
-      gtk_widget_set_sensitive (widget, FALSE);
-      break;
-    case L_EN10MB:
-#ifdef DLT_IEEE802_11
-    case L_IEEE802_11:
-#endif
-      widget = glade_xml_get_widget (xml, "fddi_radio");
-      gtk_widget_set_sensitive (widget, FALSE);
-      widget = glade_xml_get_widget (xml, "ethernet_radio");
-      gtk_widget_set_sensitive (widget, TRUE);
-      widget = glade_xml_get_widget (xml, "ieee802_radio");
-      gtk_widget_set_sensitive (widget, FALSE);
-      break;
-    case L_IEEE802:
-      widget = glade_xml_get_widget (xml, "fddi_radio");
-      gtk_widget_set_sensitive (widget, FALSE);
-      widget = glade_xml_get_widget (xml, "ethernet_radio");
-      gtk_widget_set_sensitive (widget, FALSE);
-      widget = glade_xml_get_widget (xml, "ieee802_radio");
-      gtk_widget_set_sensitive (widget, TRUE);
-      break;
-    default:
-      g_warning (_("Invalid link type %d"), linktype);
-      return;
-    }
+  /* Enable and disable link layer menu */
+  widget = glade_xml_get_widget (xml, "link_radio");
+  if (!has_linklevel())
+    gtk_widget_set_sensitive (widget, FALSE);
+  else
+    gtk_widget_set_sensitive (widget, TRUE);
 
   /* Set active mode in GUI */
-
   switch (pref.mode)
     {
-    case IEEE802:
-      widget = glade_xml_get_widget (xml, "ieee802_radio");
-      break;
-    case FDDI:
-      widget = glade_xml_get_widget (xml, "fddi_radio");
-      break;
-    case ETHERNET:
-      widget = glade_xml_get_widget (xml, "ethernet_radio");
+    case LINK6:
+      widget = glade_xml_get_widget (xml, "link_radio");
       break;
     case IP:
       widget = glade_xml_get_widget (xml, "ip_radio");
@@ -455,14 +406,8 @@ gui_start_capture (void)
 
   switch (pref.mode)
     {
-    case IEEE802:
-      g_string_append (status_string, _(" in Token Ring mode"));
-      break;
-    case FDDI:
-      g_string_append (status_string, _(" in FDDI mode"));
-      break;
-    case ETHERNET:
-      g_string_append (status_string, _(" in Ethernet mode"));
+    case LINK6:
+      g_string_append (status_string, _(" in Data Link mode"));
       break;
     case IP:
       g_string_append (status_string, _(" in IP mode"));
@@ -619,7 +564,7 @@ fatal_error_dialog (const gchar * message)
 
   error_messagebox = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 					     GTK_MESSAGE_ERROR,
-					     GTK_BUTTONS_OK, message);
+					     GTK_BUTTONS_OK, "%s", message);
   gtk_dialog_run (GTK_DIALOG (error_messagebox));
   gtk_widget_destroy (error_messagebox);
 
