@@ -18,12 +18,16 @@
  */
 
 #include <netinet/in.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 #include "globals.h"
 #include "names.h"
 #include "dns.h"
 #include "eth_resolv.h"
 #include "names_netbios.h"
 #include "protocols.h"
+#include "datastructs.h"
 #include "util.h"
 
 typedef struct
@@ -32,6 +36,7 @@ typedef struct
   guint16 offset;
   guint16 packet_size;
   packet_direction dir;
+  int link_type;
   node_id_t node_id;    /* topmost node_id: if a decoder can't fill it, it will
                          * use the lower level info */
   struct
@@ -43,7 +48,7 @@ typedef struct
 }
 name_add_t;
 
-typedef void (p_func_t) (name_add_t *);
+typedef gboolean (p_func_t) (name_add_t *);
 
 typedef struct
 {
@@ -52,45 +57,43 @@ typedef struct
 }
 prot_function_t;
 
-static void get_eth_name (name_add_t *nt);
-static void get_raw_name (name_add_t *nt);
-static void get_null_name (name_add_t *nt);
-static void get_linux_sll_name (name_add_t *nt);
-static void get_fddi_name (name_add_t *nt);
-static void get_ieee802_name (name_add_t *nt);
-static void get_llc_name (name_add_t *nt);
-static void get_arp_name (name_add_t *nt);
-static void get_ip_name (name_add_t *nt);
-static void get_ipx_name (name_add_t *nt);
-static void get_udp_name (name_add_t *nt);
-static void get_tcp_name (name_add_t *nt);
-static void get_ipxsap_name (name_add_t *nt);
-static void get_nbipx_name (name_add_t *nt);
-static void get_nbss_name (name_add_t *nt);
-static void get_nbdgm_name (name_add_t *nt);
+static gboolean get_null_name (name_add_t *nt);
+static gboolean get_linux_sll_name (name_add_t *nt);
+static gboolean get_link6_name (name_add_t *nt);
+static gboolean get_llc_name (name_add_t *nt);
+static gboolean get_arp_name (name_add_t *nt);
+static gboolean get_ip_name (name_add_t *nt);
+static gboolean get_ipv6_name (name_add_t *nt);
+static gboolean get_ipx_name (name_add_t *nt);
+static gboolean get_udp_name (name_add_t *nt);
+static gboolean get_tcp_name (name_add_t *nt);
+static gboolean get_ipxsap_name (name_add_t *nt);
+static gboolean get_nbss_name (name_add_t *nt);
+static gboolean get_nbdgm_name (name_add_t *nt);
 
-#define KNOWN_PROTS 18
-
-static prot_function_t prot_functions_table[KNOWN_PROTS + 1] = {
-  {"ETH_II", get_eth_name},
-  {"802.2", get_eth_name},
-  {"802.3", get_eth_name},
-  {"ISL", get_eth_name},
-  {"RAW", get_raw_name},
+/* not all protocol types can be useful to get a name */
+static prot_function_t prot_functions_table[] = {
+  {"ETH_II", get_link6_name},
+  {"802.2", get_link6_name},
+  {"802.3", get_link6_name},
+  {"ISL", get_link6_name},
   {"NULL", get_null_name},
   {"LINUX-SLL", get_linux_sll_name},
-  {"FDDI", get_fddi_name},
-  {"Token Ring", get_ieee802_name},
+  {"FDDI", get_link6_name},
+  {"Token Ring", get_link6_name},
   {"LLC", get_llc_name},
   {"ARP", get_arp_name},
   {"IP", get_ip_name},
+  {"IPV6", get_ipv6_name},
   {"IPX", get_ipx_name},
   {"TCP", get_tcp_name},
   {"UDP", get_udp_name},
   {"IPX-SAP", get_ipxsap_name},
-  {"IPX-NetBIOS", get_nbipx_name},
   {"NETBIOS-SSN", get_nbss_name},
-  {"NETBIOS-DGM", get_nbdgm_name}
+  {"NETBIOS-DGM", get_nbdgm_name},
+
+  /* terminator entry, must be last */
+  {NULL, NULL}
 };
 
 static void missing_data_msg(const name_add_t *nt, const char *pr)
@@ -107,7 +110,7 @@ static void missing_data_msg(const name_add_t *nt, const char *pr)
 }
 
 static void add_name (const gchar * numeric, const gchar * resolved, 
-                      gboolean solved, const node_id_t *node_id, 
+                      const node_id_t *node_id, 
                       const name_add_t *nt);
 static void decode_next(name_add_t *nt);
 
@@ -116,7 +119,8 @@ get_packet_names (protostack_t *pstk,
 		  const guint8 * packet,
 		  guint16 size,
 		  const packet_protos_t * prot_stack, 
-                  packet_direction direction)
+                  packet_direction direction,
+                  int link_type)
 {
   name_add_t nt;
 
@@ -127,12 +131,12 @@ get_packet_names (protostack_t *pstk,
   nt.packet_size = size;
   nt.dir = direction;
   nt.offset = 0;
+  nt.link_type = link_type;
   
   /* initializes decoders info 
    * Note: Level 0 means topmost - first usable is 1 
-   * We initialize as 0 because decode_next() preincrements
    */
-  nt.decoder.level = 0;
+  nt.decoder.level = 1;
   nt.decoder.tokens = prot_stack;
   nt.decoder.protos = pstk;
 
@@ -151,28 +155,30 @@ static void decode_next(name_add_t *nt)
       /* initializes proto table */
       guint i;
       prot_functions = g_tree_new ((GCompareFunc) strcmp);
-      for (i = 0; i <= KNOWN_PROTS; i++)
+      for (i = 0; prot_functions_table[i].prot != NULL ; ++i)
 	g_tree_insert (prot_functions,
 		       prot_functions_table[i].prot,
 		       &(prot_functions_table[i]));
     }
 
   g_assert(nt);
-  g_assert(nt->decoder.tokens->protonames[nt->decoder.level]); /* current level must be valid */
 
-  nt->decoder.level++;
-
-  if (!nt->decoder.tokens->protonames[nt->decoder.level])
-    return; /* no more levels, exit */
-
-  next_func = g_tree_lookup (prot_functions, nt->decoder.tokens->protonames[nt->decoder.level]);
-  if (next_func)
+  /* whe decode al most STACK_SIZE levels */
+  while (nt->decoder.level <= STACK_SIZE && 
+         nt->decoder.tokens->protonames[nt->decoder.level])
     {
-      /* before calling the next decoder, we check for size overflow */
-      if (nt->packet_size <= nt->offset)
-          return;
-  
-      next_func->function (nt);
+      next_func = g_tree_lookup (prot_functions, nt->decoder.tokens->protonames[nt->decoder.level]);
+      if (next_func)
+        {
+          /* before calling the next decoder, we check for size overflow */
+          if (nt->packet_size <= nt->offset)
+              return;
+      
+          if (! next_func->function (nt))
+            break; /* can't advance further */
+        }
+
+      nt->decoder.level++;
     }
 }
 
@@ -182,7 +188,7 @@ static void decode_next(name_add_t *nt)
  * Checks also the packet size against overflow
  */
 static void fill_node_id(node_id_t *node_id, apemode_t apemode, const name_add_t *nt, 
-                          int disp, int portdisp)
+                          int disp, int portdisp, int type)
 {
   guint8 *dt = NULL;
   size_t sz = 0;
@@ -192,75 +198,58 @@ static void fill_node_id(node_id_t *node_id, apemode_t apemode, const name_add_t
   
   switch (apemode)
   {
-  case ETHERNET:
+  case LINK6:
     dt = node_id->addr.eth;
     sz = sizeof(node_id->addr.eth);
     break;
-  case FDDI:
-    dt = node_id->addr.fddi;
-    sz = sizeof(node_id->addr.fddi);
-    break;
-  case IEEE802:
-    dt = node_id->addr.i802;
-    sz = sizeof(node_id->addr.i802);
-    break;
   case IP:
-    dt = node_id->addr.ip4;
-    sz = sizeof(node_id->addr.ip4);
+    dt = node_id->addr.ip.addr8;
+    sz = address_len(type);
     break;
   case TCP:
-    dt = node_id->addr.tcp4.host;
-    sz = sizeof(node_id->addr.tcp4); /* full size */
+    dt = node_id->addr.tcp4.host.addr8;
+    sz = address_len(type);
     break;
   default:
-    g_error (_("Unsopported ape mode in fill_node_id"));
+    g_error (_("Unsupported ape mode in fill_node_id"));
   }
 
   if (nt->packet_size < nt->offset + disp + sz ||
-     nt->packet_size < nt->offset + portdisp + sz)
+     nt->packet_size < nt->offset + portdisp + 2)
     {
       missing_data_msg(nt, NULL);
       return;
     }
 
-
   if (TCP == apemode)
   {
-    guint16 port;
-    g_memmove(dt, nt->p + nt->offset + disp, sz-2);
-    port = ntohs (*(guint16 *) (nt->p + nt->offset + portdisp));
-    g_memmove(dt+sz-2, &port, 2);
+    node_id->addr.tcp4.host.type = type;
+    g_memmove(dt, nt->p + nt->offset + disp, sz);
+    node_id->addr.tcp4.port = ntohs (*(guint16 *) (nt->p + nt->offset + portdisp));
   }
   else
+  {
+    if (IP == apemode)
+      node_id->addr.ip.type = type;
     g_memmove(dt, nt->p + nt->offset + disp, sz);
+  }
 }
 
-/* Raw is used for ppp and slip. There is actually no information,
- * so we just jump to the next protocol */
-static void
-get_raw_name (name_add_t *nt)
-{
-  decode_next(nt);
-}				/* get_raw_name */
-
 /* Null is used for loopback. There is actually no information,
  * so we just jump to the next protocol */
 /* TODO Are we so sure there is actually no information?
  * Then what are those four bytes? */
-static void
-get_null_name (name_add_t *nt)
+static gboolean get_null_name (name_add_t *nt)
 {
   nt->offset += 4;
-
-  decode_next(nt);
+  return TRUE;
 }				/* get_null_name */
 
 /* linux-sll is used for ISDN on linux, I believe. 
  * Only one of the MAC addresses involved is shown each time,
  * so by now I will simply not try to decode MAC addresses */
 /* TODO Do something useful with the address that shows */
-static void
-get_linux_sll_name (name_add_t *nt)
+static gboolean get_linux_sll_name (name_add_t *nt)
 {
   /* TODO
    * I'm assuming that the header is always size 16. I don't know
@@ -268,83 +257,56 @@ get_linux_sll_name (name_add_t *nt)
    * since ethereal is not decoding a couple of bytes, which then
    * seem to be just padding */
   nt->offset += 16;
-
-  decode_next(nt);
+  return TRUE;
 }				/* get_linux_sll_name */
 
 /* common handling for ethernet-like data */
-static void eth_name_common(apemode_t ethmode, name_add_t *nt)
+static gboolean eth_name_common(apemode_t ethmode, name_add_t *nt)
 {
   const gchar *numeric, *solved;
   gboolean found_in_ethers = FALSE;
 
   if (nt->dir == INBOUND)
-    fill_node_id(&nt->node_id, ethmode, nt, ethmode, 0);
+    fill_node_id(&nt->node_id, ethmode, nt, ethmode, 0, 0);
   else
-    fill_node_id(&nt->node_id, ethmode, nt, ethmode+6, 0);
+    fill_node_id(&nt->node_id, ethmode, nt, ethmode+6, 0, 0);
 
   numeric = ether_to_str (nt->node_id.addr.eth);
-  solved = get_ether_name (nt->node_id.addr.eth);
 
-  /* get_ether_name will return an ethernet address with
-   * the first three numbers substituted with the manufacter
-   * if it cannot find an /etc/ethers entry. If it is so,
-   * then the last 8 characters (for example ab:cd:ef) will
-   * be the same, and we will note that the name hasn't
-   * been solved */
-
-  if (numeric && solved)
-    found_in_ethers = strcmp (numeric + strlen (numeric) - 8,
-			      solved + strlen (solved) - 8);
-
-  if (found_in_ethers)
-    add_name (numeric, solved, TRUE, &nt->node_id, nt);
+  /* solved is not NULL only if the address is in ethers file */
+  if (pref.name_res)
+    solved = get_ether_name (nt->node_id.addr.eth, TRUE);
   else
-    add_name (numeric, solved, FALSE, &nt->node_id, nt);
+    solved = NULL;
+
+  add_name (numeric, solved, &nt->node_id, nt);
 
   nt->offset += 14;
-
-  decode_next(nt);
+  return TRUE;
 }
 
-static void
-get_eth_name (name_add_t *nt)
+static gboolean get_link6_name(name_add_t *nt)
 {
-  eth_name_common(ETHERNET, nt);
-}				/* get_eth_name */
-
-static void
-get_ieee802_name (name_add_t *nt)
-{
-  eth_name_common(IEEE802, nt);
-}				/* get_ieee802_name */
-
-static void
-get_fddi_name (name_add_t *nt)
-{
-  eth_name_common(FDDI, nt);
-}				/* get_fddi_name */
+  return eth_name_common(LINK6, nt);
+}
 
 /* LLC is the only supported FDDI link layer type */
-static void
-get_llc_name (name_add_t *nt)
+static gboolean get_llc_name (name_add_t *nt)
 {
   /* TODO IMPORTANT
    * We must decode the llc header to calculate the nt->offset
    * We are just doing assumptions by now */
 
-  if ((linktype == L_FDDI) || (linktype == L_IEEE802))
+  if (nt->link_type == DLT_FDDI || nt->link_type == DLT_IEEE802)
     nt->offset += 8;
-  else if (linktype == L_EN10MB)
+  else if (nt->link_type == DLT_EN10MB)
     nt->offset += 3;
   else
-    return;
-
-  decode_next(nt);
+    return FALSE; /* no further info */
+  return TRUE;
 }				/* get_llc_name */
 
-static void
-get_arp_name (name_add_t *nt)
+static gboolean get_arp_name (name_add_t *nt)
 {
   guint16 protocol_type;
   guint8 hardware_len, protocol_len;
@@ -354,72 +316,89 @@ get_arp_name (name_add_t *nt)
    * Most of the times the callee will be the broadcast 
    * address */
   if (nt->dir == INBOUND)
-    return;
+    return FALSE;
 
   if (nt->packet_size <= nt->offset + 4)
     {
       missing_data_msg(nt, "ARP");
-      return;
+      return FALSE;
     }
 
   /* We only know about IP ARP queries */
   protocol_type = pntohs ((nt->p + nt->offset + 2));
   if (protocol_type != ARPTYPE_IP)
-    return;
+    return FALSE;
 
   if (nt->packet_size <= nt->offset + 7)
     {
       missing_data_msg(nt, "ARP");
-      return;
+      return FALSE;
     }
 
   hardware_len = *(guint8 *) (nt->p + nt->offset + 4);
   protocol_len = *(guint8 *) (nt->p + nt->offset + 5);
 
-  fill_node_id(&nt->node_id, IP, nt, 8 + hardware_len, 0);
+  fill_node_id(&nt->node_id, IP, nt, 8 + hardware_len, 0, AF_INET);
 
-  add_name (ip_to_str (nt->node_id.addr.ip4), 
-            dns_lookup (pntohl (nt->node_id.addr.ip4), TRUE), 
-            TRUE, &nt->node_id, nt);
+  add_name (ipv4_to_str (nt->node_id.addr.ip.addr_v4), 
+            dns_lookup (&nt->node_id.addr.ip), 
+            &nt->node_id, nt);
 
   /* ARP doesn't carry any other protocol on top, so we return 
    * directly */
+  return FALSE;
 }				/* get_arp_name */
 
-static void
-get_ip_name (name_add_t *nt)
+static gboolean get_ip_name (name_add_t *nt)
 {
 
   if (nt->dir == INBOUND)
-    fill_node_id(&nt->node_id, IP, nt, 16, 0);
+    fill_node_id(&nt->node_id, IP, nt, 16, 0, AF_INET);
   else
-    fill_node_id(&nt->node_id, IP, nt, 12, 0);
+    fill_node_id(&nt->node_id, IP, nt, 12, 0, AF_INET);
 
   if (!pref.name_res)
-    add_name (ip_to_str (nt->node_id.addr.ip4), 
-              ip_to_str (nt->node_id.addr.ip4), FALSE, &nt->node_id, nt);
+    add_name (ipv4_to_str (nt->node_id.addr.ip.addr_v4), 
+              NULL, &nt->node_id, nt);
   else
-    {
-      add_name (ip_to_str(nt->node_id.addr.ip4), 
-                dns_lookup(pntohl (nt->node_id.addr.ip4), TRUE), 
-                TRUE, &nt->node_id, nt);
-    }
+    add_name (ipv4_to_str (nt->node_id.addr.ip.addr_v4), 
+              dns_lookup (&nt->node_id.addr.ip), 
+              &nt->node_id, nt);
 
-  nt->offset += 20;
-
-  decode_next(nt);
+  /* IPv4 header length can be variable */
+  nt->offset += nt->offset < nt->packet_size ?
+            (nt->p[nt->offset] & 15) << 2 : 0;
+  return TRUE;
 }				/* get_ip_name */
 
-static void
-get_ipx_name (name_add_t *nt)
+static gboolean get_ipv6_name (name_add_t *nt)
+{
+
+  if (nt->dir == INBOUND)
+    fill_node_id(&nt->node_id, IP, nt, 24, 0, AF_INET6);
+  else
+    fill_node_id(&nt->node_id, IP, nt, 8, 0, AF_INET6);
+
+  if (!pref.name_res)
+    add_name (ipv6_to_str (nt->node_id.addr.ip.addr_v6), 
+              NULL, &nt->node_id, nt);
+  else
+    add_name (ipv6_to_str (nt->node_id.addr.ip.addr_v6), 
+              dns_lookup (&nt->node_id.addr.ip), 
+              &nt->node_id, nt);
+
+  /* IPv6 header length is always constant */
+  nt->offset += 40;
+  return TRUE;
+}				/* get_ipv6_name */
+
+static gboolean get_ipx_name (name_add_t *nt)
 {
   nt->offset += 30;
-
-  decode_next(nt);
+  return TRUE;
 }
 
-static void
-get_tcp_name (name_add_t *nt)
+static gboolean get_tcp_name (name_add_t *nt)
 {
   guint8 th_off_x2;
   guint8 tcp_len;
@@ -428,24 +407,34 @@ get_tcp_name (name_add_t *nt)
   if (pref.mode == TCP)
     {
       gchar *numeric_name, *resolved_name;
+      int type = nt->node_id.addr.tcp4.host.type;
+      int shift = type == AF_INET6 ? 2 : 0;
+      
       if (nt->dir == OUTBOUND)
-          fill_node_id(&nt->node_id, TCP, nt, -8, 0);
+          fill_node_id(&nt->node_id, TCP, nt, -8<<shift, 0, type);
       else
-          fill_node_id(&nt->node_id, TCP, nt, -4, 2);
+          fill_node_id(&nt->node_id, TCP, nt, -4<<shift, 2, type);
 
       numeric_name = g_strdup_printf("%s:%d",
-                                     ip_to_str(nt->node_id.addr.tcp4.host),
-                                     *(guint16 *) (nt->node_id.addr.tcp4.port));
+                      address_to_str(&nt->node_id.addr.tcp4.host),
+                      nt->node_id.addr.tcp4.port);
 
-      resolved_name = g_strdup_printf("%s:%s",
-                                      dns_lookup (
-                                                  pntohl (nt->node_id.addr.tcp4.host), 
-                                                  TRUE),
-                                      get_tcp_port
-                                         (*(guint16 *)(nt->node_id.addr.tcp4.port))
-                                     );
+      if (pref.name_res)
+        {
+          const gchar *dnsname;
+          const port_service_t *port;
+          dnsname = dns_lookup (&nt->node_id.addr.tcp4.host);
+          port = services_tcp_find(nt->node_id.addr.tcp4.port);
+          if (port)
+            resolved_name = g_strdup_printf("%s:%s", dnsname, port->name);
+          else
+            resolved_name = g_strdup_printf("%s:%d", dnsname, 
+                                            nt->node_id.addr.tcp4.port);
+        }
+      else
+        resolved_name = NULL;
 
-      add_name (numeric_name, resolved_name, TRUE, &nt->node_id, nt);
+      add_name (numeric_name, resolved_name, &nt->node_id, nt);
 
       g_free (numeric_name);
       g_free (resolved_name);
@@ -454,44 +443,40 @@ get_tcp_name (name_add_t *nt)
   if (nt->packet_size <= nt->offset + 14)
     {
       missing_data_msg(nt, "TCP");
-      return;
+      return FALSE;
     }
 
   th_off_x2 = *(guint8 *) (nt->p + nt->offset + 12);
   tcp_len = hi_nibble (th_off_x2) * 4;	/* TCP header length, in bytes */
   nt->offset += tcp_len;
-
-  decode_next(nt);
+  return TRUE;
 }				/* get_tcp_name */
 
 
 /* TODO I still have to properly implement this. Right now it's just
  * a placeholder to get to the UDP/NETBIOS-DGM */
-static void
-get_udp_name (name_add_t *nt)
+static gboolean get_udp_name (name_add_t *nt)
 {
   nt->offset += 8;
-
-  decode_next(nt);
+  return TRUE;
 }				/* get_udp_name */
 
 
 /* TODO SET UP THE id's FOR THIS NETBIOS NAME FUNCTIONS */
-static void
-get_ipxsap_name (name_add_t *nt)
+static gboolean get_ipxsap_name (name_add_t *nt)
 {
   guint16 sap_type;
   guint16 curpos;
   gchar *name;
 
   if (nt->packet_size <= nt->offset + 2)
-      return; /* not a real ipxsap packet */
+      return FALSE; /* not a real ipxsap packet */
 
   sap_type = pntohs (nt->p + nt->offset);
 
   /* we want responses */
   if (sap_type != 0x0002)
-    return;
+    return FALSE;
 
   for (curpos = nt->offset + 4; curpos < nt->packet_size ; ++curpos)
     {
@@ -501,32 +486,26 @@ get_ipxsap_name (name_add_t *nt)
   if (curpos >= nt->packet_size)
     {
       missing_data_msg(nt, "IPXSAP");
-      return;
+      return FALSE;
     }
     
   name = (gchar *) (nt->p + nt->offset + 4);
 
   g_my_debug ("Sap name %s found", name);
 
-  add_name (name, name, TRUE, &nt->node_id, nt);
+  add_name (name, name, &nt->node_id, nt);
 
+  return FALSE; /* no other names */
 }				/* get_ipxsap_name */
 
-static void
-get_nbipx_name (name_add_t *nt)
-{
-
-}
-
-static void
-get_nbss_name (name_add_t *nt)
+static gboolean get_nbss_name (name_add_t *nt)
 {
 #define SESSION_REQUEST 0x81
 
   guint8 mesg_type;
 
   if (nt->packet_size < nt->offset + 1)
-      return; /* not a netbios packet */
+      return FALSE; /* not a netbios packet */
 
   mesg_type = *(guint8 *) (nt->p + nt->offset);
   nt->offset += 2;
@@ -544,7 +523,7 @@ get_nbss_name (name_add_t *nt)
       if (nt->packet_size <= nt->offset + 2)
         {
           missing_data_msg(nt, "NBSS");
-          return;
+          return FALSE;
         }
       length = pntohs ((nt->p + nt->offset + 2));
 
@@ -552,7 +531,7 @@ get_nbss_name (name_add_t *nt)
       if (nt->packet_size <= nt->offset + length)
         {
           missing_data_msg(nt, "NBSS");
-          return;
+          return FALSE;
         }
 
       name_len = ethereal_nbns_name ((const gchar *)nt->p, nt->offset, nt->packet_size, name, sizeof(name), &name_type);
@@ -575,18 +554,17 @@ get_nbss_name (name_add_t *nt)
 	    g_strdup_printf ("%s %s (%s)", name, name + NETBIOS_NAME_LEN - 1,
 			     get_netbios_host_type (name_type));
 
-	  add_name (numeric_name, name, TRUE, &nt->node_id, nt);
+	  add_name (numeric_name, name, &nt->node_id, nt);
 	  g_free (numeric_name);
 	}
 
       nt->offset += length;
     }
 
-  decode_next(nt);
+  return TRUE;
 }				/* get_nbss_name */
 
-static void
-get_nbdgm_name (name_add_t *nt)
+static gboolean get_nbdgm_name (name_add_t *nt)
 {
   guint8 mesg_type;
   gchar *numeric_name = NULL;
@@ -597,7 +575,7 @@ get_nbdgm_name (name_add_t *nt)
   guint i = 0;
 
   if (nt->packet_size < nt->offset + 1)
-    return; /* not a real nbgdm packet */
+    return FALSE; /* not a real nbgdm packet */
 
   mesg_type = *(guint8 *) (nt->p + nt->offset);
 
@@ -638,15 +616,16 @@ get_nbdgm_name (name_add_t *nt)
 	g_strdup_printf ("%s %s (%s)", name, name + NETBIOS_NAME_LEN - 1,
 			 get_netbios_host_type (name_type));
 
-      add_name (numeric_name, name, TRUE, &nt->node_id, nt);
+      add_name (numeric_name, name, &nt->node_id, nt);
       g_free (numeric_name);
     }
+  return FALSE; /* no other names */
 }				/* get_nbdgm_name */
 
 
 static void
 add_name (const gchar * numeric_name, const gchar * resolved_name, 
-          gboolean solved, const node_id_t *node_id, const name_add_t *nt)
+          const node_id_t *node_id, const name_add_t *nt)
 {
   protocol_t *protocol = NULL;
   GList *name_item = NULL;
@@ -675,7 +654,7 @@ add_name (const gchar * numeric_name, const gchar * resolved_name,
     }
 
   if (!pref.name_res)
-    node_name_assign(name, numeric_name, numeric_name, FALSE, nt->packet_size);
+    node_name_assign(name, NULL, numeric_name, nt->packet_size);
   else
-    node_name_assign(name, resolved_name, numeric_name, solved, nt->packet_size);
+    node_name_assign(name, resolved_name, numeric_name, nt->packet_size);
 }				/* add_name */
