@@ -24,4 +24,6 @@ void get_packet_names (protostack_t *pstk,
 		       const guint8 * packet,
 		       guint16 size,
 		       const packet_protos_t * prot_stack, 
-                       packet_direction direction);
+                       packet_direction direction,
+                       int link_type);
+
