@@ -32,33 +32,18 @@ static name_decode_t ethernet_sequence[] = {
     {"ETH_II", TRUE},
     {"802.2",TRUE},
     {"803.3",TRUE},
+    {"FDDI", TRUE},
+    {"IEEE802", TRUE},
     {"NETBIOS-DGM",FALSE},
     {"NETBIOS-SSN",FALSE}, 
     {"IP",FALSE},
+    {"IPV6",FALSE},
     {"IPX-SAP",FALSE},
     {"ARP",FALSE},
     {"ETH_II",FALSE},
     {"802.2",FALSE},
     {"802.3",FALSE},
-    {NULL, FALSE}
-};
-
-static name_decode_t fddi_sequence[] = { 
-    {"FDDI", TRUE},
-    {"NETBIOS-DGM",FALSE},
-    {"NETBIOS-SSN",FALSE}, 
-    {"IP",FALSE},
-    {"ARP",FALSE},
     {"FDDI",FALSE},
-    {NULL, FALSE}
-};
-
-static name_decode_t ieee802_sequence[] = { 
-    {"IEEE802", TRUE},
-    {"NETBIOS-DGM",FALSE},
-    {"NETBIOS-SSN",FALSE}, 
-    {"IP",FALSE},
-    {"ARP",FALSE},
     {"IEEE802",FALSE},
     {NULL, FALSE}
 };
@@ -67,6 +52,7 @@ static name_decode_t ip_sequence[] = {
     {"NETBIOS-DGM",FALSE},
     {"NETBIOS-SSN",FALSE}, 
     {"IP",FALSE},
+    {"IPV6",FALSE},
     {NULL, FALSE}
 };
 
@@ -131,9 +117,11 @@ void node_delete(node_t *node)
   if (!node)
     return; /* nothing to do */
 
-  g_string_free (node->name, TRUE);
+  if (node->name)
+    g_string_free (node->name, TRUE);
   node->name = NULL;
-  g_string_free (node->numeric_name, TRUE);
+  if (node->numeric_name)
+    g_string_free (node->numeric_name, TRUE);
   node->numeric_name = NULL;
 
   for (i = 0; i <= STACK_SIZE; ++i)
@@ -205,17 +193,12 @@ gchar *node_dump(const node_t * node)
 gboolean
 node_update(node_id_t * node_id, node_t *node, gpointer delete_list_ptr)
 {
-  double pkt_expire_time;
   struct timeval diff;
 
   g_assert(delete_list_ptr);
 
-  if (pref.node_timeout_time && pref.node_timeout_time < pref.averaging_time)
-    pkt_expire_time = pref.node_timeout_time;
-  else
-    pkt_expire_time = pref.averaging_time;
-
-  if (traffic_stats_update(&node->node_stats, pkt_expire_time, pref.proto_node_timeout_time))
+  if (traffic_stats_update(&node->node_stats, pref.averaging_time, 
+                            pref.proto_node_timeout_time))
     {
       /* packet(s) active, update the most used protocols for this link */
       guint i = STACK_SIZE;
@@ -285,15 +268,9 @@ node_name_update(node_t * node)
 
   switch (pref.mode)
     {
-    case ETHERNET:
+    case LINK6:
       set_node_name (node, ethernet_sequence);
       break;
-    case FDDI:
-      set_node_name (node, fddi_sequence);
-      break;
-    case IEEE802:
-      set_node_name (node, ieee802_sequence);
-      break;
     case IP:
       set_node_name (node, ip_sequence);
       break;
@@ -348,7 +325,7 @@ set_node_name (node_t * node, const name_decode_t *sequence)
           if (DEBUG_ENABLED)
             {
               gchar *msgname = node_name_dump(name);
-              if (name->solved || !iter->must_resolve)
+              if (name->res_name || !iter->must_resolve || !pref.name_res)
                 g_my_debug("  found protocol with name [%s]", msgname);
               else
                 g_my_debug("  found protocol with UNRESOLVED name [%s], ignored", 
@@ -358,14 +335,18 @@ set_node_name (node_t * node, const name_decode_t *sequence)
 
           /* If we require this protocol to be solved and it's not,
            * the we have to go on */
-          if (name->solved || !iter->must_resolve)
+          if (name->res_name || !iter->must_resolve || !pref.name_res)
             {
-              if (!node->name || strcmp (node->name->str, name->name->str))
+              if (name->res_name)
                 {
-                  g_my_debug ("  set node name from %s to %s",
-                              (node->name) ? node->name->str : "none",
-                              name->name->str);
-                  g_string_assign (node->name, name->name->str);
+                  if (!node->name || 
+                      strcmp (node->name->str, name->res_name->str))
+                    {
+                      g_my_debug ("  set node name from %s to %s",
+                                  (node->name) ? node->name->str : "<none>",
+                                  name->res_name->str);
+                      g_string_assign (node->name, name->res_name->str);
+                    }
                 }
               if (!node->numeric_name || 
                   strcmp(node->numeric_name->str, name->numeric_name->str))
