@@ -82,7 +82,8 @@ void init_config(struct pref_struct *p)
   p->interface=NULL;
   p->filter=NULL;
   p->debug_mask = (G_LOG_LEVEL_MASK & ~(G_LOG_LEVEL_DEBUG | G_LOG_LEVEL_INFO));
-  p->max_delay = G_MAXUINT;
+  p->min_delay = 0;
+  p->max_delay = G_MAXULONG;
 }
 
 
@@ -97,6 +98,11 @@ load_config (const char *prefix)
 
   config_file_version =
     gnome_config_get_string_with_default("General/version=0.5.4", &u);
+
+  /* for now, those two preferences aren't saved */
+  pref.mode = gnome_config_get_int_with_default ("General/mode=1", &u); /* IP */
+  pref.filter = gnome_config_get_string_with_default("General/filter=ip or ip6", &u);
+
   pref.diagram_only =
     gnome_config_get_bool_with_default ("Diagram/diagram_only=FALSE", &u);
   pref.group_unk =
@@ -135,7 +141,6 @@ load_config (const char *prefix)
     ("Diagram/link_node_ratio=1.0", &u);
   if (u)
     pref.link_node_ratio = 1.0;
-  pref.mode = gnome_config_get_int_with_default ("General/mode=-1", &u);	/* DEFAULT */
   pref.refresh_period =
       gnome_config_get_int_with_default ("Diagram/refresh_period=100", &u);
 
@@ -303,6 +308,7 @@ copy_config(struct pref_struct *tgt, const struct pref_struct *src)
   tgt->filter = g_strdup(src->filter);
 
   tgt->debug_mask = src->debug_mask;
+  tgt->min_delay = src->min_delay;
   tgt->max_delay = src->max_delay;
 }
 
