@@ -1,7 +1,7 @@
 
 /* Etherape
  * Copyright (C) 2005 Juan Toledo, R.Ghetta
- * $Id: protocols.h,v 1.31 2006/01/12 21:13:42 bchiara Exp $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,34 +21,28 @@
 #ifndef PROTOCOLS_H
 #define PROTOCOLS_H
 
-#include "pkt_info.h"
-
-#define STACK_SIZE 5		/* How many protocol levels to keep
-				 * track of (+1) */
+#include "basic_stats.h"
+#include "node_id.h"
 
 /* Information about each protocol heard on a link */
 typedef struct
 {
   gchar *name;			/* Name of the protocol */
-  gdouble average;		/* Average bytes in or out in the last x ms */
-  gdouble aver_accu;		/* Accumulated bytes in the last x ms */
-  gdouble accumulated;		/* Accumulated traffic in bytes for this protocol */
-  guint proto_packets;		/* Number of packets seen with this protocol */
-  GList *node_names;		/* Has a list of all node names used with this
-				 * protocol (used in node protocols) */
-  struct timeval last_heard;	/* The last at which this protocol carried traffic */
-}
-protocol_t;
+  basic_stats_t stats;
+  GList *node_names;		/* A list of all node names (name_t) used with
+				 * this protocol (used in node protocols) */
+} protocol_t;
 
 protocol_t *protocol_t_create(const gchar *protocol_name);
 void protocol_t_delete(protocol_t *prot);
+/* returns a new string with a dump of prot */
+gchar *protocol_t_dump(const protocol_t *prot);
 
 typedef struct
 {
   GList *protostack[STACK_SIZE + 1];	/* It's a stack. Each level is a list of 
                                          * all protocol_t heard at that level */
-}
-protostack_t;
+} protostack_t;
 
 /* protocol stack methods */
 void protocol_stack_open(protostack_t *pstk);
@@ -65,7 +59,8 @@ void protocol_stack_purge_expired(protostack_t *pstk, double expire_time);
 const protocol_t *protocol_stack_find(const protostack_t *pstk, size_t level, const gchar *protoname);
 /* sorts on the most used protocol in the requested level and returns it */
 gchar *protocol_stack_sort_most_used(protostack_t *pstk, size_t level);
-
+/* returns a newly allocated string with a dump of pstk */
+gchar *protocol_stack_dump(const protostack_t *pstk);
 
 
 /* protocol summary method */
@@ -73,7 +68,7 @@ void protocol_summary_open(void); /* initializes the summary */
 void protocol_summary_close(void); /* frees summary, releasing resources */
 void protocol_summary_add_packet(packet_info_t *packet); /* adds a new packet to summary */
 void protocol_summary_update_all(void); /* update stats on protocol summary */
-guint protocol_summary_size(size_t level); /* number of protos at specified level */
+long protocol_summary_size(void); /* total number of protos */
 void protocol_summary_foreach(size_t level, GFunc func, gpointer data); /* calls func for every proto at level */
 const protocol_t *protocol_summary_find(size_t level, const gchar *protoname); /* finds named protocol */
 const protostack_t *protocol_summary_stack(void); /* access directly the stack (only for proto windows) */
